@@ -1,8 +1,8 @@
 // SPDX-License-Identifier: Apache-2.0
 // Copyright (C) 2021 Profian, Inc.
 
-#![feature(asm, if_let_guard)]
 #![warn(clippy::all)]
+#![allow(clippy::useless_conversion)]
 
 mod api;
 mod cmdline;
@@ -11,9 +11,9 @@ mod efi;
 mod formats;
 mod iotools;
 
+use clap::Parser;
 use commands::Command;
-use structopt::StructOpt;
 
 fn main() -> anyhow::Result<()> {
-    commands::Main::from_args().execute()
+    commands::Main::parse().execute()
 }
